@@ -84,6 +84,9 @@ class SpiderController(Thread):
             except DropRequestException as e:
                 logger.warning(f"丢弃请求：{' '.join(list(e.args))}")
             except Exception as e:
+                if settings.SPIDER_STOP_ON_ERROR:
+                    raise
+
                 # spider 报错处理
                 for middleware in self.spider.SPIDER_MIDDLEWARE:
                     middleware.spider_error(self.spider, e)
